@@ -9,6 +9,7 @@ from aitool.basic_function.file import load_json as load_json
 from aitool.basic_function.file import dump_pickle as dump_pickle
 from aitool.basic_function.file import load_pickle as load_pickle
 from aitool.basic_function.file import dump_lines as dump_lines
+from aitool.basic_function.file import load_lines as load_line
 from aitool.basic_function.file import load_lines as load_lines
 from aitool.basic_function.file import dump_excel as dump_excel
 from aitool.basic_function.file import load_excel as load_excel
@@ -42,3 +43,6 @@ from aitool.task_customized.ip_enhance.filter import is_all_chinese
 from aitool.task_customized.ip_enhance.filter import is_black_name
 from aitool.task_customized.ip_enhance.filter import clean_role
 from aitool.task_customized.ip_enhance.filter import clean_alias
+from aitool.task_customized.ip_enhance.filter import delete_nested_text
+from aitool.task_customized.ip_enhance.filter import select_nested_text
+from aitool.task_customized.ip_enhance.filter import get_core_ip
